aboutsummaryrefslogtreecommitdiff
path: root/nix
diff options
context:
space:
mode:
Diffstat (limited to 'nix')
-rw-r--r--nix/configuration.nix1
-rw-r--r--nix/deuxfleurs.nix4
2 files changed, 3 insertions, 2 deletions
diff --git a/nix/configuration.nix b/nix/configuration.nix
index 68751a2..4eb701b 100644
--- a/nix/configuration.nix
+++ b/nix/configuration.nix
@@ -77,6 +77,7 @@ SystemMaxUse=1G
# Enable the OpenSSH daemon and disable password login.
services.openssh.enable = true;
services.openssh.settings.PasswordAuthentication = false;
+ services.openssh.ports = [ 110 ];
virtualisation.docker = {
enable = true;
diff --git a/nix/deuxfleurs.nix b/nix/deuxfleurs.nix
index 45a64c0..1b9ae3d 100644
--- a/nix/deuxfleurs.nix
+++ b/nix/deuxfleurs.nix
@@ -412,8 +412,8 @@ in
enable = true;
allowedTCPPorts = [
- # Allow anyone to connect on SSH port
- (head ({ openssh.ports = [22]; } // config.services).openssh.ports)
+ # Allow anyone to connect on SSH port on tcp/110, port 22 is used by forgejo
+ (head ({ openssh.ports = [ 110 ]; } // config.services).openssh.ports)
];
allowedUDPPorts = [